.. _pipelines:

Transdimensional Pipelines
==========================

**Transdimensional Pipelines** break the lens modeling procedure down into a series of linked model-fits, providing
automated and efficient fits to the most complex lens models

The readthedocs overview for **Transdimensional Pipelines** is not written yet. However, checkout
`Chapter 3 of the HowToLens lectures <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/index.html>`_
for a complete description.